==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Model/Event.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Event.cxx
 *  @brief The class that implements all random vectors
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-29 16:13:02 +0200 (mar 29 mai 2007) $
 *  Id:      $Id: Event.cxx 450 2007-05-29 14:13:02Z dutka $
 */
#include "Event.hxx"


namespace OpenTURNS {

  namespace Uncertainty {

    namespace Model {

      CLASSNAMEINIT(Event);

      /* Constructor from RandomVector */
      Event::Event(const RandomVector & antecedent,
		   const ComparisonOperator & op,
		   const NumericalScalar threshold,
		   const String & name)
	throw (InvalidArgumentException)
	: RandomVector(antecedent, op, threshold, name)
      {
	// Nothing to do
      }

      /* String converter */
      String Event::str() const {
	OSS oss;
	oss << "class=" << Event::GetClassName()
	    << " name=" << getName()
	    << " implementation=" << getImplementation()->str();
	return oss;
      }
  
    } /* namespace Model */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Model/Event.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Event.cxx
 *  @brief The class that implements all random vectors
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: Event.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "Event.hxx"


namespace OpenTURNS {

  namespace Uncertainty {

    namespace Model {

      CLASSNAMEINIT(Event);

      /* Constructor from RandomVector */
      Event::Event(const RandomVector & antecedent,
		   const ComparisonOperator & op,
		   const NumericalScalar threshold,
		   const String & name)
	/* throw (InvalidArgumentException) */
	: RandomVector(antecedent, op, threshold, name)
      {
	// Nothing to do
      }

      /* String converter */
      String Event::__repr__() const {
	OSS oss;
	oss << "class=" << Event::GetClassName()
	    << " name=" << getName()
	    << " implementation=" << getImplementation()->__repr__();
	return oss;
      }
  
      /* String converter */
      String Event::__str__() const {
	return __repr__();
      }
  
    } /* namespace Model */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
